.. genestboost documentation master file, created by
   sphinx-quickstart on Sun Dec  1 22:26:50 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to genestboost's documentation!
=======================================

:code:`genestboost` is an ML boosting library that separates the modeling algorithm from the boosting algorithm. The result is that you can boost any generic regression model, not just trees. Build a forward-thinking (forward-propagating) neural network if you wish, or build an ensemble of support vector machines if you would so desire. Mix and match link and loss functions at will.

.. image:: images/qr_different_alg_plot.png

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   quick_coding_example
   examples
   custom_link_function
   custom_loss_function
   model_callbacks
   weak_learners
   modules
   installation
   changelog
   GitHub Repo <https://github.com/btcross26/genestboost>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
